@@ -19,9 +19,10 @@
 */
 
 #include "KReportItemWeb.h"
-#include <KReportRenderObjects.h>
+#include "KReportUtils.h"
+#include "KReportRenderObjects.h"
 
-#include <KProperty>
+#include <KPropertyListData>
 #include <KPropertySet>
 
 #include <QGraphicsRectItem>
@@ -32,52 +33,40 @@
 
 #include "kreportplugin_debug.h"
 
-KReportItemWeb::KReportItemWeb(): m_rendering(false)
+KReportItemWeb::KReportItemWeb() : m_rendering(false), m_targetPage(nullptr)
 {
     createProperties();
-    init();
+    m_webPage = new QWebPage();
+    connect(m_webPage, SIGNAL(loadFinished(bool)), this, SLOT(loadFinished(bool)));
 }
 
 KReportItemWeb::KReportItemWeb(const QDomNode &element)
+    : KReportItemWeb()
 {
-    createProperties();
-    init();
+    QDomElement e = element.toElement();
+
+    setItemDataSource(e.attribute(QLatin1String("report:item-data-source")));
+    nameProperty()->setValue(KReportUtils::readNameAttribute(e));
+    setZ(e.attribute(QLatin1String("report:z-index")).toDouble());
+    parseReportRect(e);
     QDomNodeList nl = element.childNodes();
     QString n;
     QDomNode node;
-    QDomElement e = element.toElement();
-
-    m_controlSource->setValue(element.toElement().attribute(QLatin1String("report:item-data-source")));
-    m_name->setValue(element.toElement().attribute(QLatin1String("report:name")));
-    Z = element.toElement().attribute(QLatin1String("report:z-index")).toDouble();
-    parseReportRect(element.toElement(), &m_pos, &m_size);
     for (int i = 0; i < nl.count(); i++) {
         node = nl.item(i);
         n = node.nodeName();
     }
 }
 
-void KReportItemWeb::init()
-{
-    m_webPage = new QWebPage();
-
-    connect(m_webPage, SIGNAL(loadFinished(bool)), this, SLOT(loadFinished(bool)));
-}
-
 void KReportItemWeb::createProperties()
 {
-    m_set = new KPropertySet;
-
-    m_controlSource = new KProperty("item-data-source", QStringList(),
-                                    QStringList(), QString(), tr("Data Source"));
-    m_set->addProperty(m_controlSource);
-    addDefaultProperties();
+    createDataSourceProperty();
 }
 
 KReportItemWeb::~KReportItemWeb()
 {
-    delete m_set;
 }
+
 QString KReportItemWeb::typeName() const
 {
     return QLatin1String("web");
@@ -88,7 +77,7 @@ void KReportItemWeb::loadFinished(bool)
     //kreportpluginDebug() << m_rendering;
     if (m_rendering) {
         OROPicture * pic = new OROPicture();
-        m_webPage->setViewportSize(m_size.toScene().toSize());
+        m_webPage->setViewportSize(sceneSize(size()).toSize());
         m_webPage->mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
         m_webPage->mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
 
@@ -96,18 +85,22 @@ void KReportItemWeb::loadFinished(bool)
 
         m_webPage->mainFrame()->render(&p);
 
-        QPointF pos = m_pos.toScene();
-        QSizeF size = m_size.toScene();
+        QPointF pos = scenePosition(position());
+        QSizeF siz = sceneSize(size());
 
         pos += m_targetOffset;
 
         pic->setPosition(pos);
-        pic->setSize(size);
-        if (m_targetPage) m_targetPage->addPrimitive(pic, false, true);
+        pic->setSize(siz);
+        if (m_targetPage) m_targetPage->insertPrimitive(pic);
 
         OROPicture *p2 = dynamic_cast<OROPicture*>(pic->clone());
-        p2->setPosition(m_pos.toPoint());
-        if (m_targetSection) m_targetSection->addPrimitive(p2);
+        if (p2) {
+            p2->setPosition(scenePosition(position()));
+            if (m_targetSection) {
+                m_targetSection->addPrimitive(p2);
+            }
+        }
 
         m_rendering = false;
         emit(finishedRendering());
@@ -136,8 +129,3 @@ int KReportItemWeb::renderSimpleData(OROPage *page, OROSection *section, const Q
 
     return 0; //Item doesn't stretch the section height
 }
-
-QString KReportItemWeb::itemDataSource() const
-{
-    return m_controlSource->value().toString();
-}
